/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo;

/**
 * Interface for classes returning partial information about application.
 *
 * @author Marcin Zajączkowski, 2010-07-01
 */
public interface ApplicationInfo {

    String DEFAULT_NAME = "Really unknown app";
    String DEFAULT_VERSION = "devel";
    String DEFAULT_BUILD_NUMBER = "devel";
    String DEFAULT_BUILD_DATE = "devel";
    String DEFAULT_SCM_REVISION = "head";

    /**
     * Returns application name.
     *
     * @return application name
     */
    String getName();

    /**
     * Returns application version.
     *
     * @return application version
     */
    String getVersion();

    /**
     * Returns current build number (np. from CI server).
     *
     * @return build number
     */
    String getBuildNumber();

    /**
     * Returns creation date of current build.
     *
     * @return build creation date
     */
    String getBuildDate();

    /**
     * Returns current SCM revision.
     *
     * @return SCM revision
     *
     * @since 0.5.1
     */
    String getScmRevision();
}
