/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.reader;

import net.sf.appinfo.exception.ReaderInitializationException;
import net.sf.appinfo.util.AssertUtil;

import java.io.IOException;
import java.io.InputStream;
import java.util.jar.Manifest;

/**
 * ManifestReader implementation reading manifest from given file.
 *
 * @author Marcin Zajączkowski, 2010-07-01
 */
public class FileManifestReader extends AbstractManifestReader {

    private final String pathToManifest;

    /**
     * Creates reader with set given path to a manifest file.
     *
     * @param pathToManifest path to manifest file
     */
    public FileManifestReader(String pathToManifest) {
        super();
        AssertUtil.notNull(pathToManifest, "pathToManifest");
        this.pathToManifest = pathToManifest;
    }

    /** {@inheritDoc} */
    @Override
    protected Manifest initializeAndReturnManifest() throws ReaderInitializationException, IOException {
        InputStream streamToManifest = getClass().getResourceAsStream(pathToManifest);
        if (streamToManifest == null) {
            throw new ReaderInitializationException("Input stream for manifest file '" + pathToManifest + "' is null");
        } else {
            return new Manifest(streamToManifest);
        }
    }
}
