/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.reader;

import net.sf.appinfo.exception.ReaderInitializationException;

import java.io.IOException;
import java.net.URL;
import java.util.jar.Manifest;

/**
 * ManifestReader implementation getting manifest from a JAR file.
 *
 * Proper JAR is pointed by a class places within an archive.
 *
 * @author Marcin Zajączkowski, 2010-07-01
 */
public class JarManifestReader extends AbstractManifestReader {

    private final Class<?> classFromJar;

    /**
     * Uses itself (this) as a class in JAR which manifest file will be looked for.
     */
    public JarManifestReader() {
        super();
        this.classFromJar = getClass();
    }

    /**
     * Uses given class as a class in JAR which manifest file will be looked for.
     *
     * @param classFromJar class from JAR
     */
    public JarManifestReader(Class<?> classFromJar) {
        super();
        this.classFromJar = classFromJar;
    }

    @Override
    protected Manifest initializeAndReturnManifest() throws ReaderInitializationException, IOException {
        //Based on: http://forums.sun.com/thread.jspa?messageID=10061355#10061355
        String classContainer = classFromJar.getProtectionDomain().getCodeSource().getLocation().toString();
        URL manifestUrl = new URL("jar:" + classContainer + "!/META-INF/MANIFEST.MF");
        return new Manifest(manifestUrl.openStream());
    }
}
