/* Copyright (c) 2010 Marcin Zajaczkowski
 * All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.appinfo.reader;

import net.sf.appinfo.exception.ReaderInitializationException;
import net.sf.appinfo.util.AssertUtil;

import javax.servlet.ServletContext;
import java.io.IOException;
import java.util.jar.Manifest;

/**
 * ManifestReader implementation using ServletContext.
 *
 * To be used in web applications.
 *
 * TODO: MZA: Write some integration tests (with Arquillian?)
 *
 * @author Marcin Zajączkowski, 2010-11-03
 */
public class ServletContextManifestReader extends AbstractManifestReader {

    private final ServletContext servletContext;

    public ServletContextManifestReader(ServletContext servletContext) {
        super();
        AssertUtil.notNull(servletContext, "servletContext");
        this.servletContext = servletContext;
    }

    @Override
    protected Manifest initializeAndReturnManifest() throws ReaderInitializationException, IOException {
        return new Manifest(servletContext.getResourceAsStream("/META-INF/MANIFEST.MF"));
    }
}
